@@ -7,7 +7,7 @@ os.environ['DJANGO_SETTINGS_MODULE'] = '%s.settings' % settings.PROJECT_MODULE
 sys.path.insert(0, settings.PROJECT_PARENT_DIR)
 
 def runtests():
-	call_command('test', 'django_config_gen')
+	call_command('test')
 	sys.exit()
 
 if __name__ == '__main__':
